pub struct DetectService<D, S> {
pub detector: D,
pub inner: S,
}Expand description
DetectService is a service that detects a certain pattern in the input stream and forwards the detected pattern and the wrapped input stream to the inner service.
Fields
detector: Dinner: STrait Implementations
Sourceimpl<R, S, D, CX> Service<(R, CX)> for DetectService<D, S>
impl<R, S, D, CX> Service<(R, CX)> for DetectService<D, S>
Sourcetype Response = <S as Service<(<D as Detect<R>>::DetOut, <D as Detect<R>>::IOOut, CX)>>::Response
type Response = <S as Service<(<D as Detect<R>>::DetOut, <D as Detect<R>>::IOOut, CX)>>::Response
The type of response returned by this service.