pub struct PrefixDetector(pub &'static [u8]);Expand description
PrefixDetector detects a certain prefix from the input stream.
If the prefix matches, it returns true and the wrapped input stream with the prefix data. Otherwise, it returns false and the input stream with the prefix data(the prefix maybe less than the static str’s length).
Tuple Fields
0: &'static [u8]Trait Implementations