Struct HttpServerTimeout

pub struct HttpServerTimeout {
    pub keepalive_timeout: Option<Duration>,
    pub read_header_timeout: Option<Duration>,
    pub read_body_timeout: Option<Duration>,
}
Represents the timeout settings for the HTTP server.

The HttpServerTimeout struct contains three optional fields:

  • keepalive_timeout: The timeout for keeping the connection alive. If no byte is received within this timeout, the connection will be closed.
  • read_header_timeout: The timeout for reading the full HTTP header.
  • read_body_timeout: The timeout for receiving the full request body.

By default, the keepalive_timeout is set to 75 seconds, while the other two timeouts are not set.

Fields

keepalive_timeout: Option<Duration>read_header_timeout: Option<Duration>read_body_timeout: Option<Duration>