pub struct ConnectionReuseHandler<H> { /* private fields */ }Expand description
Handler for managing HTTP connection persistence and keep-alive behavior.
ConnectionReuseHandler is responsible for:
- Detecting whether an incoming request supports keep-alive.
- Modifying request and response headers to ensure proper keep-alive behavior.
- Handling version-specific connection persistence logic for HTTP/1.0, HTTP/1.1, and HTTP/2.
For implementation details and example usage, see the module level documentation.
Implementations
Sourceimpl<F> ConnectionReuseHandler<F>
impl<F> ConnectionReuseHandler<F>
pub fn layer<C>() -> impl FactoryLayer<C, F, Factory = Self>