Struct DetectService

pub struct DetectService<D, S> {
    pub detector: D,
    pub inner: S,
}
DetectService is a service that detects a certain pattern in the input stream and forwards the detected pattern and the wrapped input stream to the inner service.

Fields

detector: Dinner: S