pub struct ContentHandler<H> { /* private fields */ }Expand description
Handles content encoding and decoding for HTTP requests and responses.
ContentHandler is responsible for:
- Decoding the content of incoming requests based on their Content-Encoding header.
- Encoding the content of outgoing responses based on the client’s Accept-Encoding preferences.
It wraps an inner handler and preprocesses requests before passing them to the inner handler, as well as postprocessing responses from the inner handler. For implementation details and example usage, see the module level documentation.
Implementations
Sourceimpl<F> ContentHandler<F>
impl<F> ContentHandler<F>
pub fn layer<C>() -> impl FactoryLayer<C, F, Factory = Self>
Sourcepub fn opt_layer<C>(
enabled: bool,
) -> Option<impl FactoryLayer<C, F, Factory = Self>>
pub fn opt_layer<C>( enabled: bool, ) -> Option<impl FactoryLayer<C, F, Factory = Self>>
Returns a factory layer for the ContentHandler.
This allows the ’ContentHandler to be selectively enabled or disabled based on a configuration at runtime.